#include <QApplication>
#include <QtGui>
#include <QtWidgets>
//#include <QGLWidget>

class MyView : public QGraphicsView
{
    Q_OBJECT

public:
    explicit MyView(QGraphicsScene* scene, QWidget* parent = 0) :
        QGraphicsView(scene, parent),
        count(0)
    {
        //
    }

signals:
    void trace(const QString& trace);

protected:
    virtual void drawForeground (QPainter* painter, const QRectF& rect)
    {
        emit trace(QString("Redraw # %1").arg(++count));
    }

private:
    int count;
};

#include "main.moc"

int main(int argc, char ** argv)
{
    QApplication app(argc, argv);

    QGraphicsEllipseItem* item = new QGraphicsEllipseItem(10, 10, 100, 100);
    item->setPen(QPen(Qt::red));

    QGraphicsScene* scene = new QGraphicsScene;
    scene->addItem(item);

    MyView* view = new MyView(scene);
    QStatusBar* bar = new QStatusBar();

    // NB: issue occurs only with QOpenGLWidget ; commenting the
    // next line or using a QGLWidget will solve the issue
    view->setViewport(new QOpenGLWidget);
    //view->setViewport(new QGLWidget);

    // NB: QueuedConnection needed with QOpenGLWidget to avoid
    // "QWidget::repaint: Recursive repaint detected" warnings
    // this connection doesn't cause any issue with other viewports
    QObject::connect(view, SIGNAL(trace(QString)), bar, SLOT(showMessage(QString)), Qt::QueuedConnection);

    QMainWindow mainWindow;
    mainWindow.setCentralWidget(view);
    mainWindow.setStatusBar(bar);
    mainWindow.show();

    return app.exec();
}
